@@ -85,11 +85,7 @@ class GTKGUI(GUIModule):
 
                 win = hildon.StackableWindow()
             except Exception:
-                import sys
-
-                e = sys.exc_info()[1]
-                print("creating hildon stackable window failed")
-                print(e)
+                self.log.exception("creating hildon stackable window failed")
                 win = gtk.Window()
         else:
             win = gtk.Window()
@@ -115,6 +111,10 @@ class GTKGUI(GUIModule):
         self.topWindow = win
         self.modrana.addTime("map widget created")
 
+        # check if we should start in fullscreen
+        if self.shouldStartInFullscreen():
+            self.setFullscreen(True)
+
         # Event handling
         event_box = gtk.EventBox()
 
@@ -151,14 +151,9 @@ class GTKGUI(GUIModule):
             try:
                 gtk.show_uri(None, url, gtk.gdk.CURRENT_TIME)
             except Exception:
-                import sys
-
-                e = sys.exc_info()[1]
-                print("GTK GUI: calling gtk.show_uri() failed, probably due to old GTK version")
-                print(e)
-                print("using the webbrowser module as fallback")
+                self.log.exception("calling gtk.show_uri() failed, probably due to old GTK version")
+                self.log.warning("using the webbrowser module as fallback")
                 import webbrowser
-
                 webbrowser.open(url)
 
     def resize(self, w, h):
@@ -196,9 +191,11 @@ class GTKGUI(GUIModule):
         if value:
             self.mw.topWindow.fullscreen()
             self.fullscreen = True
+            self.log.info("going to fullscreen")
         else:
             self.mw.topWindow.unfullscreen()
             self.fullscreen = False
+            self.log.info("going out of fullscreen")
 
 
     def enableDefaultDrag(self):
@@ -297,11 +294,7 @@ class GTKGUI(GUIModule):
         try:
             self._updateCenteringShiftCB()
         except Exception:
-            import sys
-
-            e = sys.exc_info()[1]
-            print("GTK GUI: initial centering shift update failed")
-            print(e)
+            self.log.exception("initial centering shift update failed")
 
         # watch centering shift related variables
         self.watch('posShiftAmount', self._updateCenteringShiftCB)
@@ -372,6 +365,8 @@ class MainWidget(gtk.Widget):
         self.dmod = gui.modrana.dmod # device specific module
         self.currentDrawMethod = self.fullDrawMethod
 
+        self._log = self.gui.log
+
         self.centeringDisableThreshold = 2048
 
         # press length timing
@@ -383,9 +378,6 @@ class MainWidget(gtk.Widget):
         self.dragX = 0
         self.dragY = 0
 
-        """ setting this both to 100 and 1 in mapView and gpsd fixes the arrow
-         orientation bug """
-        self.timer1 = gobject.timeout_add(100, self.update, self) #default 100
         self.timer3 = None # will be used for timing long press events
 
         self.notMovingSpeed = 1 # in m/s
@@ -430,12 +422,6 @@ class MainWidget(gtk.Widget):
         then terminate the GTK main loop"""
         gtk.main_quit()
 
-    def update(self):
-        """ trigger periodic module update """
-        # TODO: depreciate this
-        # in favor of event based and explicit update timers
-        self.modrana.update()
-
     def get(self, key, defaultValue):
         """local alias for the modRana persistent dictionary get function"""
         self.modrana.get(key, defaultValue)
@@ -444,6 +430,10 @@ class MainWidget(gtk.Widget):
         """local alias for the modRana persistent dictionary set function"""
         self.modrana.set(key, value)
 
+    @property
+    def log(self):
+        return self._log
+
     def _checkForRedrawCB(self, key, oldValue, newValue):
         """react to redraw requests"""
         if newValue == True:
@@ -463,11 +453,7 @@ class MainWidget(gtk.Widget):
             try:
                 self.window.invalidate_rect((0, 0, self.rect.width, self.rect.height), False)
             except Exception:
-                import sys
-
-                e = sys.exc_info()[1]
-                print("error in screen invalidating function"
-                      "exception: %s" % e)
+                self.log.exception("error in screen invalidating function")
 
     def pressed(self, w, event):
         """Press-handler"""
@@ -533,7 +519,7 @@ class MainWidget(gtk.Widget):
         # but better be safe, than eat the whole battery if the timer is not terminated
         dt = (time.time() - pressStartTime) * 1000
         if dt > 60000:
-            print("long press timeout reached")
+            self.log.debug("long press timeout reached")
             return False
 
         if pressStartEpoch == self.lastPressEpoch and self.pressInProgress:
@@ -547,7 +533,6 @@ class MainWidget(gtk.Widget):
         m = self.modrana.getModule("clickHandler", None)
         if m:
             m.handleClick(x, y, msDuration)
-            self.update()
 
     def handleDrag(self, x, y, dx, dy, startX, startY, msDuration):
         """handle dragging on the screen"""
@@ -602,7 +587,7 @@ class MainWidget(gtk.Widget):
         if self.showRedrawTime:
             redrawTime = (1000 * (time.clock() - start))
             timestamp = time.time()
-            print("Redraw took %1.2f ms at(%1.4f)" % (redrawTime, timestamp))
+            self.log.debug("Redraw took %1.2f ms at(%1.4f)", redrawTime, timestamp)
         self.lastFullRedraw = time.time()
 
     def getLastFullRedraw(self):
@@ -622,7 +607,7 @@ class MainWidget(gtk.Widget):
             if menus:
                 menus.mainDrawMenu(cr, menuName)
             else:
-                print("GTK GUI: error, menu module missing")
+                self.log.error("error, menu module missing")
         else: # draw the map
             cr.set_source_rgb(0.2, 0.2, 0.2) # map background
             cr.rectangle(0, 0, self.rect.width, self.rect.height)
@@ -656,13 +641,7 @@ class MainWidget(gtk.Widget):
                     for m in modules:
                         m.drawMapOverlay(cr)
                 except Exception:
-                    import sys
-
-                    e = sys.exc_info()[1]
-                    print("modRana GTK main loop: an exception occurred")
-                    print(e)
-                    print('modRana GTK main loop: traceback:')
-                    traceback.print_exc(file=sys.stdout) # find what went wrong
+                    self.log.exception("modRana GTK main loop: an exception occurred")
                 cr.restore()
                 cr.translate(-x, -y)
                 for m in modules:
@@ -674,13 +653,7 @@ class MainWidget(gtk.Widget):
                     for m in modules:
                         m.drawMapOverlay(cr)
                 except Exception:
-                    import sys
-
-                    e = sys.exc_info()[1]
-                    print("modRana GTK main loop: an exception occurred")
-                    print(e)
-                    print('modRana GTK main loop: traceback:')
-                    traceback.print_exc(file=sys.stdout) # find what went wrong
+                    self.log.exception("modRana GTK main loop: an exception occurred")
                 for m in modules:
                     m.drawScreenOverlay(cr)
 
@@ -741,7 +714,7 @@ class MainWidget(gtk.Widget):
         try:
             (sx, sy, w, h) = self.modrana.get('viewport', None)
         except TypeError:
-            print("gtk gui: viewport not available")
+            self.log.error("viewport not available")
             return
 
         # store current screen content in backing pixmap
@@ -815,7 +788,7 @@ class MainWidget(gtk.Widget):
         newW = allocation[2]
         newH = allocation[3]
 
-        print("GTK GUI: size allocation", allocation)
+        self.log.debug("size allocation: %r", allocation)
         # resize the backing pixmap
         self.initGCandBackingPixmap(self.allocation.width, self.allocation.height)
 
