@@ -21,9 +21,7 @@
 #---------------------------------------------------------------------------
 from __future__ import with_statement
 import os
-import sys
 import re
-import traceback
 
 import pyotherside
 
@@ -43,6 +41,7 @@ from core import constants
 from core.threads import threadMgr
 from core import geo
 from core import modrana_log
+from core import utils
 
 import logging
 log = logging.getLogger("mod.gui.qt5")
@@ -113,9 +112,6 @@ class QMLGUI(GUIModule):
             "tile" : TileImageProvider(self),
         }
 
-        with open("data/tile_not_found.png", "rb") as f:
-            self._tileNotFoundImage = f.read()
-
         ## register the actual callback, that
         ## will call the appropriate provider base on
         ## image id prefix
@@ -322,7 +318,14 @@ class QMLGUI(GUIModule):
             "fullscreenOnly": self.modrana.dmod.fullscreenOnly(),
             "shouldStartInFullscreen": self.shouldStartInFullscreen(),
             "needsBackButton": self.modrana.dmod.needsBackButton(),
-            "needsPageBackground": self.modrana.dmod.needsPageBackground()
+            "needsPageBackground": self.modrana.dmod.needsPageBackground(),
+            "lastKnownPos" : self.get("pos", None),
+            "gpsEnabled" : self.get("GPSEnabled", True),
+            "posFromFile" : self.get("posFromFile", None),
+            "nmeaFilePath" : self.get("NMEAFilePath", None),
+            "layerTree" : self.modules.mapLayers.getLayerTree(),
+            "dictOfLayerDicts" : self.modules.mapLayers.getDictOfLayerDicts(),
+            "themesFolderPath" : os.path.abspath(self.modrana.paths.getThemesFolderPath())
         }
         return values
 
@@ -462,7 +465,7 @@ class IconImageProvider(ImageProvider):
             splitPath[-1] = splitPath[-1].rsplit("?")[0]
             fullIconPath = os.path.join(themeFolder, *splitPath)
 
-            if not os.path.exists(fullIconPath):
+            if not utils.internal_isfile(fullIconPath):
                 if splitPath[0] == constants.DEFAULT_THEME_ID:
                     # already on default theme and icon path does not exist
                     log.error("Icon not found in default theme:")
@@ -471,15 +474,12 @@ class IconImageProvider(ImageProvider):
                 else:  # try to get the icon from default theme
                     splitPath[0] = constants.DEFAULT_THEME_ID
                     fullIconPath = os.path.join(themeFolder, *splitPath)
-                    if not os.path.exists(fullIconPath):
+                    if not utils.internal_isfile(fullIconPath):
                         # icon not found even in the default theme
                         log.error("Icon not found even in default theme:")
                         log.error(fullIconPath)
                         return None
-            with open(fullIconPath, 'rb') as f:
-                # the context manager will make sure the icon
-                # file is properly closed
-                return bytearray(f.read()), (-1,-1), pyotherside.format_data
+            return utils.internal_get_file_contents(fullIconPath), (-1,-1), pyotherside.format_data
         except Exception:
             log.exception("icon image provider: loading icon failed, id:\n%s" % imageId)
 
@@ -493,6 +493,7 @@ class TileImageProvider(ImageProvider):
         self.gui = gui
 
         self.gui.firstTimeSignal.connect(self._firstTimeCB)
+        self._tileNotFoundImage = bytearray([0, 255, 255, 255])
 
     def _firstTimeCB(self):
         # connect to the tile downloaded callback so that we can notify
@@ -546,10 +547,8 @@ class TileImageProvider(ImageProvider):
                 # completed signal.
                 #
                 # We notify the GUI by returning a 1x1 image.
-                tileData = self.gui._tileNotFoundImage
-                imageSize = (1,1)
+                return self._tileNotFoundImage, (1,1), pyotherside.format_argb32
                 #log.debug("%s NOT FOUND" % imageId)
-                # TODO: use some raw image data instead of PNG ?
             #log.debug("RETURNING STUFF %d %s" % (imageSize[0], imageId))
             return bytearray(tileData), imageSize, pyotherside.format_data
         except Exception:
@@ -762,4 +761,4 @@ class Theme(object):
             }
         }
         self._themeDict = themeDict
-        return themeDict
\ No newline at end of file
+        return themeDict
