@@ -27,6 +27,9 @@ import struct
 from signals_pb2 import CommandType, VersionCommand, VersionResult, RoutingCommand, RoutingResult
 from signals_pb2 import Node as Waypoint
 
+import logging
+log = logging.getLogger("mod.routing.monav")
+
 
 class TcpConnection(object):
     """Wrapper for socket.socket() with Google protocol buffers.
@@ -154,8 +157,8 @@ def get_route(data_directory, waypoints, lookup_radius=10000, lookup_edge_names=
     #            waypoint = command.waypoints.add(latitude=latlon[0], longitude=latlon[1])
 
     # Write the command.
-    print("COMMAND")
-    print(command)
+    log.debug("COMMAND")
+    log.debug(command)
 
     connection.write(command)
 
