@@ -63,24 +63,23 @@ class ShowOSD(RanaModule):
 
     def drawScreenOverlay(self, cr):
         """ draw currently active information widgets TODO: just draw object from list"""
-        if self.m.get('config', {}):
-            config = self.modrana.configs.getUserConfig()
+        config = self.modrana.configs.getUserConfig()
 
-            mode = self.get('mode', None)
-            if mode is None:
-                return
+        mode = self.get('mode', None)
+        if mode is None:
+            return
 
-            if mode not in config:
-                return
-            if 'OSD' in config[mode]:
-                items = config[mode]['OSD']
-                # we don't know the nearest point when refreshing the screen
-                # TODO: don't search for nearest point on every refresh ?
-                self.nearestPoint = None
-                self.nearestIndex = None
-                self.distanceList = None
-                for item in items:
-                    self.drawWidget(cr, items[item], item)
+        if mode not in config:
+            return
+        if 'OSD' in config[mode]:
+            items = config[mode]['OSD']
+            # we don't know the nearest point when refreshing the screen
+            # TODO: don't search for nearest point on every refresh ?
+            self.nearestPoint = None
+            self.nearestIndex = None
+            self.distanceList = None
+            for item in items:
+                self.drawWidget(cr, items[item], item)
 
 
     def drawWidget(self, cr, item, type):
@@ -241,7 +240,7 @@ class ShowOSD(RanaModule):
         pos = self.get('pos', None)
         if pos is None:
             return False
-        #    print(profile)
+        #    self.log.debug(profile)
 
         #    (sx,sy) = proj.screenPos(0.5, 0.5)
         #    (sLat,sLon) = proj.xy2ll(sx, sy)
@@ -269,7 +268,7 @@ class ShowOSD(RanaModule):
             return
 
         #    profile = self.routeProfileData
-        #    print(item)
+        #    self.log.debug(item)
 
         proj = self.m.get('projection', None)
         (px, py) = float(item['px']), float(item['py'])
@@ -307,7 +306,7 @@ class ShowOSD(RanaModule):
 
         leftIndex = nearestIndex - nrPoints / 2
         rightIndex = nearestIndex + nrPoints / 2
-        #    print(leftAdd, leftIndex, nearestIndex, rightIndex, rightAdd)
+        #    self.log.debug(leftAdd, leftIndex, nearestIndex, rightIndex, rightAdd)
         if leftIndex < 0:
             leftAdd = abs(leftIndex)
             leftIndex = 0
@@ -316,8 +315,8 @@ class ShowOSD(RanaModule):
             rightIndex = totalLength - 1
 
 
-        #    print(totalLength)
-        #    print(leftAdd, leftIndex, nearestIndex, rightIndex, rightAdd)
+        #    self.log.debug(totalLength)
+        #    self.log.debug(leftAdd, leftIndex, nearestIndex, rightIndex, rightAdd)
 
         # build
 
