@@ -23,6 +23,8 @@ from modules.base_module import RanaModule
 from core.signal import Signal
 from core.backports import six
 
+from core import utils
+
 import logging
 log = logging.getLogger("mod.theme")
 
@@ -81,7 +83,7 @@ class ThemeModule(RanaModule):
         :returns: a list of available theme ids
         :rtype: a list of strings
         """
-        rawFolderContent = os.listdir(self.modrana.paths.getThemesFolderPath())
+        rawFolderContent = utils.internal_listdir(self.modrana.paths.getThemesFolderPath())
         # append the full path and filter out all dot-folders, such as .svn, .git & co
         themesFolderPath = self.modrana.paths.getThemesFolderPath()
         return filter(
@@ -133,7 +135,17 @@ class Theme(object):
     def _loadConfigFile(self, path):
         """load color definitions from file"""
 
-        config = ConfigObj(path)
+        try:
+            if utils.internal_isfile(path):
+                config_content = utils.internal_get_file_contents(path)
+                config = ConfigObj(config_content.decode().split("\n"))
+
+            else:
+                log.error("theme config file %s does not exist", path)
+                return
+        except Exception:
+            log.exception("loading theme config file from %s failed", path)
+            return
 
         # try to get theme name from the config
         try:
